@@ -1,6 +1,6 @@
 package POE::Filter::IRCv3;
 {
-  $POE::Filter::IRCv3::VERSION = '0.042000';
+  $POE::Filter::IRCv3::VERSION = '0.042001';
 }
 
 use strictures 1;
@@ -95,6 +95,9 @@ sub get_one {
 }
 
 
+use bytes;
+
+
 sub put {
   my ($self, $events) = @_;
   my $raw_lines = [];
@@ -126,9 +129,11 @@ sub put {
             $param = shift @params;
           }
           $raw_line .= ':'
-            if $self->[COLONIFY]
-            or $event->{colonify}
-            or $param =~ m/\x20/;
+            if (index($param, SPCHR) != -1)
+            or (
+              defined $event->{colonify} ?
+              $event->{colonify} : $self->[COLONIFY]
+            );
           $raw_line .= $param;
       }
 
@@ -151,8 +156,6 @@ sub _parseline {
 
   my $pos = 0;
 
-  use bytes;
-
   if ( substr($raw_line, $pos, 1) eq '@' ) {
     my $nextsp = index $raw_line, SPCHR, $pos;
     return unless $nextsp > 0;
@@ -213,6 +216,9 @@ sub _parseline {
 }
 
 
+no bytes;
+
+
 1;
 
 
